@@ -24,7 +24,7 @@ sub new {
     # set up the environment, including authentication info
     # only copy %ENV if we are changing anything
     my $env; 
-    if($r->dir_config('AuthServerVariables')) {
+    if(&config($asp, 'AuthServerVariables')) {
 	if(defined $r->get_basic_auth_pw) {
 	    $env = { %ENV };
 	    my $c = $r->connection;
@@ -47,9 +47,9 @@ sub new {
 	if($ENV{CONTENT_TYPE}=~ m|^multipart/form-data|) {
 	    # do the logic here so that the normal form POST processing will not
 	    # occur either
-	    $asp->{file_upload_process} = defined $r->dir_config('FileUploadProcess') ? $r->dir_config('FileUploadProcess') : 1;
+	    $asp->{file_upload_process} = &config($asp, 'FileUploadProcess', undef, 1);
 	    if($asp->{file_upload_process}) {
-		if($asp->{file_upload_temp} = $r->dir_config('FileUploadTemp')) {
+		if($asp->{file_upload_temp} = &config($asp, 'FileUploadTemp')) {
 		    eval "use CGI;";
 		} else {
 		    # default leaves no temp files for prying eyes
@@ -64,17 +64,21 @@ sub new {
 		# before it used to error abruptly, now it will simply skip the file 
 		# upload data
 		local $CGI::DISABLE_UPLOADS = $CGI::DISABLE_UPLOADS;
-		if($asp->{file_upload_max} = $r->dir_config('FileUploadMax')) {
+		if($asp->{file_upload_max} = &config($asp, 'FileUploadMax')) {
 		    if($self->{TotalBytes} > $asp->{file_upload_max} ) {
 			$CGI::DISABLE_UPLOADS = 1;
 		    }
 		}
 		
-		$asp->{dbg} && $asp->Debug("using CGI.pm version ".(eval { CGI->VERSION } || $CGI::VERSION).
-				       " for file upload support");
+		$asp->{dbg} && $asp->Debug("using CGI.pm version ".
+					   (eval { CGI->VERSION } || $CGI::VERSION).
+					   " for file upload support"
+					  );
+		$asp->Debug($CGI::DISABLE_UPLOADS, '---', $self, '---', $asp->{r}->dir_config);
 
 		my %form;
 		my $q = $self->{cgi} = new CGI;
+		$asp->Debug($q->param);
 		for(my @names = $q->param) {
 		    my @params = $q->param($_);
 		    $form{$_} = @params > 1 ? [ @params ] : $params[0];
@@ -86,7 +90,7 @@ sub new {
 			    $upload{$_}{TempFile} = $q->tmpFileName($fh);
 			    $upload{$_}{TempFile} =~ s|^/+|/|;
 			}
-			$upload{$_}{BrowserFile} = $fh;
+			$upload{$_}{BrowserFile} = "$fh";
 			$upload{$_}{FileHandle} = $fh;
 			$upload{$_}{ContentType} = $upload{$_}{'Content-Type'};
 			# tie the file upload reference to a collection... %upload
@@ -124,7 +128,7 @@ ASP_REQUEST_POST_READ_DONE:
     my $parsed_query = $query ? &ParseParams($self, \$query) : {};
     $self->{'QueryString'} = bless $parsed_query, 'Apache::ASP::Collection';
 
-    if($r->dir_config('RequestParams')) {
+    if(&config($asp, 'RequestParams')) {
 	$self->{'Params'} = bless { %$parsed_query, %$form }, 'Apache::ASP::Collection';
     } 
 
@@ -166,6 +170,7 @@ sub DESTROY {
 	}
 	$self->{FileUpload}{$_} = undef;
     }
+
     %$self = ();
 }
 
@@ -262,7 +267,7 @@ sub ParseParams {
 	    # &Unescape($self, $_) 
 	    my $todecode = $_;
 	    $todecode =~ tr/+/ /;       # pluses become spaces
-	    $todecode =~ s/%([0-9a-fA-F]{2})/pack("c",hex($1))/ge;
+	    $todecode =~ s/%([0-9a-fA-F]{2})/chr(hex($1))/ge;
 	    $todecode;
 	} split (/\=/, $pair, 2);
 	if(defined $params{$key}) {
@@ -292,4 +297,6 @@ sub Unescape {
     $todecode;
 }
 
+*config = *Apache::ASP::config;
+
 1;
